@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __BUILDVECTOR_HPP__
-#define __BUILDVECTOR_HPP__
+#pragma once
 
 #include <algorithm>
 
@@ -44,5 +43,3 @@ public:
 private:
   std::vector<V> _vector;
 };
-
-#endif
