@@ -43,6 +43,8 @@ namespace mergerfs
       dropcacheonclose(false),
       symlinkify(false),
       symlinkify_timeout(3600),
+      nullrw(false),
+      ignorepponrename(false),
       POLICYINIT(access),
       POLICYINIT(chmod),
       POLICYINIT(chown),
