@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __CONFIG_HPP__
-#define __CONFIG_HPP__
+#pragma once
 
 #include <fuse.h>
 
@@ -51,6 +50,8 @@ namespace mergerfs
     bool                     dropcacheonclose;
     bool                     symlinkify;
     time_t                   symlinkify_timeout;
+    bool                     nullrw;
+    bool                     ignorepponrename;
 
   public:
     const Policy  *policies[FuseFunc::Enum::END];
@@ -104,5 +105,3 @@ namespace mergerfs
     }
   };
 }
-
-#endif
