@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __CREATE_HPP__
-#define __CREATE_HPP__
+#pragma once
 
 #include <fuse.h>
 
@@ -31,5 +30,3 @@ namespace mergerfs
            fuse_file_info *ffi);
   }
 }
-
-#endif
