@@ -14,8 +14,6 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#if FALLOCATE
-
 #include <fuse.h>
 
 #include "errno.hpp"
@@ -56,5 +54,3 @@ namespace mergerfs
     }
   }
 }
-
-#endif
