@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FGETATTR_HPP__
-#define __FGETATTR_HPP__
+#pragma once
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -31,5 +30,3 @@ namespace mergerfs
              fuse_file_info *fileinfo);
   }
 }
-
-#endif
