@@ -137,7 +137,7 @@ namespace fs
 
   int
   findonfs(const vector<string> &srcmounts,
-           const char           *fusepath,
+           const string         &fusepath,
            const int             fd,
            string               &basepath)
   {
@@ -218,6 +218,13 @@ namespace fs
     return ::fcntl(fd,F_GETFL,0);
   }
 
+  int
+  setfl(const int    fd,
+        const mode_t mode)
+  {
+    return ::fcntl(fd,F_SETFL,mode);
+  }
+
   int
   mfs(const vector<string> &basepaths,
       const uint64_t        minfreespace,
