@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_ACCESS_HPP__
-#define __FS_BASE_ACCESS_HPP__
+#pragma once
 
 #include <string>
 
@@ -56,5 +55,3 @@ namespace fs
     return fs::access(path,mode,AT_EACCESS);
   }
 }
-
-#endif
