@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_CHOWN_HPP__
-#define __FS_BASE_CHOWN_HPP__
+#pragma once
 
 #include <string>
 
@@ -140,5 +139,3 @@ namespace fs
     return 0;
   }
 }
-
-#endif
