@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_FTRUNCATE_HPP__
-#define __FS_BASE_FTRUNCATE_HPP__
+#pragma once
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -33,5 +32,3 @@ namespace fs
     return ::ftruncate(fd,size);
   }
 }
-
-#endif
