@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_GETXATTR_HPP__
-#define __FS_BASE_GETXATTR_HPP__
+#pragma once
 
 #include <sys/types.h>
 
@@ -41,5 +40,3 @@ namespace fs
 #endif
   }
 }
-
-#endif
