@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_LINK_HPP__
-#define __FS_BASE_LINK_HPP__
+#pragma once
 
 #include <string>
 
@@ -34,5 +33,3 @@ namespace fs
     return ::link(oldpath.c_str(),newpath.c_str());
   }
 }
-
-#endif
