@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_LSEEK_HPP__
-#define __FS_BASE_LSEEK_HPP__
+#pragma once
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -34,5 +33,3 @@ namespace fs
     return ::lseek(fd,offset,whence);
   }
 }
-
-#endif
