@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_MKNOD_HPP__
-#define __FS_BASE_MKNOD_HPP__
+#pragma once
 
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -36,5 +35,3 @@ namespace fs
     return ::mknod(path.c_str(),mode,dev);
   }
 }
-
-#endif
