@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_OPEN_HPP__
-#define __FS_BASE_OPEN_HPP__
+#pragma once
 
 #include <string>
 
@@ -46,5 +45,3 @@ namespace fs
     return ::open(path.c_str(),flags,mode);
   }
 }
-
-#endif
