@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_READLINK_HPP__
-#define __FS_BASE_READLINK_HPP__
+#pragma once
 
 #include <string>
 
@@ -35,5 +34,3 @@ namespace fs
     return ::readlink(path.c_str(),buf,bufsiz);
   }
 }
-
-#endif
