@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_RENAME_HPP__
-#define __FS_BASE_RENAME_HPP__
+#pragma once
 
 #include <stdio.h>
 
@@ -32,5 +31,3 @@ namespace fs
     return ::rename(oldpath.c_str(),newpath.c_str());
   }
 }
-
-#endif
