@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_SETXATTR_HPP__
-#define __FS_BASE_SETXATTR_HPP__
+#pragma once
 
 #include <sys/types.h>
 
@@ -42,5 +41,3 @@ namespace fs
 #endif
   }
 }
-
-#endif
