@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_UNLINK_HPP__
-#define __FS_BASE_UNLINK_HPP__
+#pragma once
 
 #include <string>
 
@@ -33,5 +32,3 @@ namespace fs
     return ::unlink(path.c_str());
   }
 }
-
-#endif
