@@ -16,8 +16,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_UTIME_GENERIC_HPP__
-#define __FS_BASE_UTIME_GENERIC_HPP__
+#pragma once
 
 #include <string>
 
@@ -312,5 +311,3 @@ namespace fs
     return ::futimes(fd,tvp);
   }
 }
-
-#endif
