@@ -25,6 +25,8 @@
 #include "fs_base_chmod.hpp"
 #include "fs_base_chown.hpp"
 #include "fs_base_close.hpp"
+#include "fs_base_fadvise.hpp"
+#include "fs_base_fallocate.hpp"
 #include "fs_base_lseek.hpp"
 #include "fs_base_mkdir.hpp"
 #include "fs_base_open.hpp"
@@ -32,8 +34,6 @@
 #include "fs_base_stat.hpp"
 #include "fs_base_utime.hpp"
 #include "fs_base_write.hpp"
-#include "fs_fadvise.hpp"
-#include "fs_fallocate.hpp"
 #include "fs_sendfile.hpp"
 #include "fs_xattr.hpp"
 
@@ -57,19 +57,18 @@ writen(const int     fd,
   ssize_t nwritten;
 
   nleft = count;
-  while(nleft > 0)
+  do
     {
       nwritten = fs::write(fd,buf,nleft);
+      if((nwritten == -1) && (errno == EINTR))
+        continue;
       if(nwritten == -1)
-        {
-          if(errno == EINTR)
-            continue;
-          return -1;
-        }
+        return -1;
 
       nleft -= nwritten;
       buf   += nwritten;
     }
+  while(nleft > 0);
 
   return count;
 }
@@ -96,12 +95,12 @@ copyfile_rw(const int    fdin,
   while(totalwritten < count)
     {
       nr = fs::read(fdin,&buf[0],bufsize);
+      if(nr == 0)
+        return totalwritten;
+      if((nr == -1) && (errno == EINTR))
+        continue;
       if(nr == -1)
-        {
-          if(errno == EINTR)
-            continue;
-          return -1;
-        }
+        return -1;
 
       nw = writen(fdout,&buf[0],nr);
       if(nw == -1)
@@ -110,7 +109,7 @@ copyfile_rw(const int    fdin,
       totalwritten += nw;
     }
 
-  return count;
+  return totalwritten;
 }
 
 static
@@ -122,8 +121,8 @@ copydata(const int    fdin,
 {
   int rv;
 
-  fs::fadvise(fdin,0,count,POSIX_FADV_WILLNEED);
-  fs::fadvise(fdin,0,count,POSIX_FADV_SEQUENTIAL);
+  fs::fadvise_willneed(fdin,0,count);
+  fs::fadvise_sequential(fdin,0,count);
 
   fs::fallocate(fdout,0,0,count);
 
@@ -176,11 +175,11 @@ namespace fs
     if((rv == -1) && !ignorable_error(errno))
       return -1;
 
-    rv = fs::fchown(fdout,stin);
+    rv = fs::fchown_check_on_error(fdout,stin);
     if(rv == -1)
       return -1;
 
-    rv = fs::fchmod(fdout,stin);
+    rv = fs::fchmod_check_on_error(fdout,stin);
     if(rv == -1)
       return -1;
 
