@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_CLONEFILE_HPP__
-#define __FS_CLONEFILE_HPP__
+#pragma once
 
 #include <string>
 
@@ -26,5 +25,3 @@ namespace fs
   int clonefile(const std::string &from,
                 const std::string &to);
 }
-
-#endif
