@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_PATH_HPP__
-#define __FS_PATH_HPP__
+#pragma once
 
 #include <string>
 #include <vector>
@@ -38,6 +37,14 @@ namespace fs
       base += suffix;
     }
 
+    inline
+    void
+    append(string       &base,
+           const string &suffix)
+    {
+      base += suffix;
+    }
+
     inline
     void
     make(const string *base,
@@ -47,7 +54,15 @@ namespace fs
       output  = *base;
       output += suffix;
     }
+
+    inline
+    void
+    make(const string *base,
+         const string &suffix,
+         string       &output)
+    {
+      output  = *base;
+      output += suffix;
+    }
   }
 };
-
-#endif // __FS_PATH_HPP__
