@@ -14,10 +14,6 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
 #include <fuse.h>
 
 #include <string>
@@ -52,8 +48,7 @@ namespace mergerfs
     {
       FileInfo *fi = reinterpret_cast<FileInfo*>(ffi->fh);
 
-      return _fsync(fi->fd,
-                    isdatasync);
+      return ::_fsync(fi->fd,isdatasync);
     }
   }
 }
