@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FSYNC_HPP__
-#define __FSYNC_HPP__
+#pragma once
 
 #include <fuse.h>
 
@@ -29,5 +28,3 @@ namespace mergerfs
           fuse_file_info *fi);
   }
 }
-
-#endif
