@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FTRUNCATE_HPP__
-#define __FTRUNCATE_HPP__
+#pragma once
 
 #include <fuse.h>
 
@@ -32,5 +31,3 @@ namespace mergerfs
               fuse_file_info *fi);
   }
 }
-
-#endif
