@@ -49,6 +49,8 @@ _listxattr_controlfile(char         *list,
     ("user.mergerfs.dropcacheonclose")
     ("user.mergerfs.symlinkify")
     ("user.mergerfs.symlinkify_timeout")
+    ("user.mergerfs.nullrw")
+    ("user.mergerfs.ignorepponrename")
     ("user.mergerfs.policies")
     ("user.mergerfs.version")
     ("user.mergerfs.pid");
