@@ -70,15 +70,12 @@ namespace local
   static
   void
   get_fuse_operations(struct fuse_operations &ops,
-                      const bool              direct_io)
+                      const bool              direct_io,
+                      const bool              nullrw)
   {
     ops.flag_nullpath_ok   = true;
-#if FLAG_NOPATH
     ops.flag_nopath        = true;
-#endif
-#if FLAG_UTIME
     ops.flag_utime_omit_ok = true;
-#endif
 
     ops.access      = mergerfs::fuse::access;
     ops.bmap        = NULL;
@@ -86,13 +83,9 @@ namespace local
     ops.chown       = mergerfs::fuse::chown;
     ops.create      = mergerfs::fuse::create;
     ops.destroy     = mergerfs::fuse::destroy;
-#if FALLOCATE
     ops.fallocate   = mergerfs::fuse::fallocate;
-#endif
     ops.fgetattr    = mergerfs::fuse::fgetattr;
-#if FLOCK
     ops.flock       = mergerfs::fuse::flock;
-#endif
     ops.flush       = mergerfs::fuse::flush;
     ops.fsync       = mergerfs::fuse::fsync;
     ops.fsyncdir    = mergerfs::fuse::fsyncdir;
@@ -110,12 +103,14 @@ namespace local
     ops.open        = mergerfs::fuse::open;
     ops.opendir     = mergerfs::fuse::opendir;
     ops.poll        = NULL;
-    ops.read        = direct_io ?
-      mergerfs::fuse::read_direct_io :
-      mergerfs::fuse::read;
-#if READ_BUF
-    ops.read_buf    = mergerfs::fuse::read_buf;
-#endif
+    ops.read        = (nullrw ?
+                       mergerfs::fuse::read_null :
+                       (direct_io ?
+                        mergerfs::fuse::read_direct_io :
+                        mergerfs::fuse::read));
+    ops.read_buf    = (nullrw ?
+                       NULL :
+                       mergerfs::fuse::read_buf);
     ops.readdir     = mergerfs::fuse::readdir;
     ops.readlink    = mergerfs::fuse::readlink;
     ops.release     = mergerfs::fuse::release;
@@ -130,12 +125,14 @@ namespace local
     ops.unlink      = mergerfs::fuse::unlink;
     ops.utime       = NULL;       /* deprecated; use utimens() */
     ops.utimens     = mergerfs::fuse::utimens;
-    ops.write       = direct_io ?
-      mergerfs::fuse::write_direct_io :
-      mergerfs::fuse::write;
-#if WRITE_BUF
-    ops.write_buf   = mergerfs::fuse::write_buf;
-#endif
+    ops.write       = (nullrw ?
+                       mergerfs::fuse::write_null :
+                       (direct_io ?
+                        mergerfs::fuse::write_direct_io :
+                        mergerfs::fuse::write));
+    ops.write_buf   = (nullrw ?
+                       mergerfs::fuse::write_buf_null :
+                       mergerfs::fuse::write_buf);
 
     return;
   }
@@ -171,7 +168,9 @@ namespace mergerfs
     mergerfs::options::parse(args,config);
 
     local::setup_resources();
-    local::get_fuse_operations(ops,config.direct_io);
+    local::get_fuse_operations(ops,
+                               config.direct_io,
+                               config.nullrw);
 
     return fuse_main(args.argc,
                      args.argv,
