@@ -14,17 +14,14 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __NUM_HPP__
-#define __NUM_HPP__
-
-#include <string>
+#pragma once
 
 #include <stdint.h>
 
+#include <string>
+
 namespace num
 {
   int to_uint64_t(const std::string &str, uint64_t &value);
   int to_time_t(const std::string &str, time_t &value);
 }
-
-#endif
