@@ -190,6 +190,10 @@ parse_and_process_kv_arg(Config            &config,
         rv = parse_and_process(value,config.symlinkify);
       else if(key == "symlinkify_timeout")
         rv = parse_and_process(value,config.symlinkify_timeout);
+      else if(key == "nullrw")
+        rv = parse_and_process(value,config.nullrw);
+      else if(key == "ignorepponrename")
+        rv = parse_and_process(value,config.ignorepponrename);
     }
 
   if(rv == -1)
@@ -291,15 +295,13 @@ usage(void)
     "    -o symlinkify_timeout=<int>\n"
     "                           timeout in seconds before will turn to symlinks.\n"
     "                           default=3600\n"
-            << std::endl;
-}
-
-static
-void
-version(void)
-{
-  std::cout << "mergerfs version: "
-            << MERGERFS_VERSION
+    "    -o nullrw=<bool>       Disables reads and writes. For benchmarking.\n"
+    "    -o ignorepponrename=<bool>\n"
+    "                           Ignore path preserving when performing renames\n"
+    "                           and links. default = false\n"
+    "    -o threads=<int>       number of worker threads. 0 = autodetect.\n"
+    "                           Negative values autodetect then divide by\n"
+    "                           absolute value. default = 0\n"
             << std::endl;
 }
 
@@ -333,7 +335,9 @@ option_processor(void       *data,
       break;
 
     case MERGERFS_OPT_VERSION:
-      version();
+      std::cout << "mergerfs version: "
+                << (MERGERFS_VERSION[0] ? MERGERFS_VERSION : "unknown")
+                << std::endl;
       fuse_opt_add_arg(outargs,"--version");
       break;
 
