@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __STATVFS_UTIL_HPP__
-#define __STATVFS_UTIL_HPP__
+#pragma once
 
 #include <string>
 
@@ -49,5 +48,3 @@ namespace StatVFS
     return (st.f_frsize * (st.f_blocks - st.f_bavail));
   }
 }
-
-#endif
