@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __STR_HPP__
-#define __STR_HPP__
+#pragma once
 
 #include <string>
 #include <vector>
@@ -58,5 +57,3 @@ namespace str
   isprefix(const std::string &s0,
            const std::string &s1);
 }
-
-#endif
