@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __SUCCESS_FAIL_HPP__
-#define __SUCCESS_FAIL_HPP__
+#pragma once
 
 #define STATVFS_SUCCESS 0
 #define STATVFS_SUCCEEDED(RV) ((RV) == STATVFS_SUCCESS)
@@ -42,5 +41,3 @@
 #define RENAME_FAIL -1
 #define RENAME_FAILED(RV) ((RV) == RENAME_FAIL)
 #define RENAME_FAILED_WITH(RV,ERRNO) (((RV) == RENAME_FAIL) && (errno == ERRNO))
-
-#endif
