@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __TRUNCATE_HPP__
-#define __TRUNCATE_HPP__
+#pragma once
 
 #include <sys/types.h>
 
@@ -28,5 +27,3 @@ namespace mergerfs
              off_t       size);
   }
 }
-
-#endif
