@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __WRITE_HPP__
-#define __WRITE_HPP__
+#pragma once
 
 namespace mergerfs
 {
@@ -34,7 +33,12 @@ namespace mergerfs
                     size_t          count,
                     off_t           offset,
                     fuse_file_info *fi);
+
+    int
+    write_null(const char     *fusepath,
+               const char     *buf,
+               size_t          count,
+               off_t           offset,
+               fuse_file_info *fi);
   }
 }
-
-#endif
