@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __WRITE_BUF_HPP__
-#define __WRITE_BUF_HPP__
+#pragma once
 
 #include <fuse.h>
 
@@ -30,7 +29,11 @@ namespace mergerfs
               struct fuse_bufvec *buf,
               off_t               offset,
               fuse_file_info     *fi);
+
+    int
+    write_buf_null(const char         *fusepath,
+                   struct fuse_bufvec *buf,
+                   off_t               offset,
+                   fuse_file_info     *fi);
   }
 }
-
-#endif
